==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/DiskEncryptionSetResourceSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.DiskEncryptionSetResourceSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines the disk encryption set resource settings.
 * @property resourceType The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
 * Expected value is 'Microsoft.Compute/diskEncryptionSets'.
 * @property targetResourceGroupName Gets or sets the target resource group name.
 * @property targetResourceName Gets or sets the target Resource name.
 */
public data class DiskEncryptionSetResourceSettingsArgs(
    public val resourceType: Output<String>,
    public val targetResourceGroupName: Output<String>? = null,
    public val targetResourceName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.DiskEncryptionSetResourceSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.DiskEncryptionSetResourceSettingsArgs =
        com.pulumi.azurenative.migrate.inputs.DiskEncryptionSetResourceSettingsArgs.builder()
            .resourceType(resourceType.applyValue({ args0 -> args0 }))
            .targetResourceGroupName(targetResourceGroupName?.applyValue({ args0 -> args0 }))
            .targetResourceName(targetResourceName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DiskEncryptionSetResourceSettingsArgs].
 */
@PulumiTagMarker
public class DiskEncryptionSetResourceSettingsArgsBuilder internal constructor() {
    private var resourceType: Output<String>? = null

    private var targetResourceGroupName: Output<String>? = null

    private var targetResourceName: Output<String>? = null

    /**
     * @param value The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
     * Expected value is 'Microsoft.Compute/diskEncryptionSets'.
     */
    @JvmName("obkulkeexpcpusut")
    public suspend fun resourceType(`value`: Output<String>) {
        this.resourceType = value
    }

    /**
     * @param value Gets or sets the target resource group name.
     */
    @JvmName("qommkxshwjrxrpbj")
    public suspend fun targetResourceGroupName(`value`: Output<String>) {
        this.targetResourceGroupName = value
    }

    /**
     * @param value Gets or sets the target Resource name.
     */
    @JvmName("pyunbiigikoqtysn")
    public suspend fun targetResourceName(`value`: Output<String>) {
        this.targetResourceName = value
    }

    /**
     * @param value The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
     * Expected value is 'Microsoft.Compute/diskEncryptionSets'.
     */
    @JvmName("mlufcswcxsttxwvi")
    public suspend fun resourceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceType = mapped
    }

    /**
     * @param value Gets or sets the target resource group name.
     */
    @JvmName("edmmuknaophmbnoj")
    public suspend fun targetResourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetResourceGroupName = mapped
    }

    /**
     * @param value Gets or sets the target Resource name.
     */
    @JvmName("tfljditfusmpdxkq")
    public suspend fun targetResourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetResourceName = mapped
    }

    internal fun build(): DiskEncryptionSetResourceSettingsArgs =
        DiskEncryptionSetResourceSettingsArgs(
            resourceType = resourceType ?: throw PulumiNullFieldException("resourceType"),
            targetResourceGroupName = targetResourceGroupName,
            targetResourceName = targetResourceName ?: throw PulumiNullFieldException("targetResourceName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/DiskEncryptionSetResourceSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.DiskEncryptionSetResourceSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines the disk encryption set resource settings.
 * @property resourceType The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
 * Expected value is 'Microsoft.Compute/diskEncryptionSets'.
 * @property targetResourceGroupName Gets or sets the target resource group name.
 * @property targetResourceName Gets or sets the target Resource name.
 */
public data class DiskEncryptionSetResourceSettingsArgs(
    public val resourceType: Output<String>,
    public val targetResourceGroupName: Output<String>? = null,
    public val targetResourceName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.DiskEncryptionSetResourceSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.DiskEncryptionSetResourceSettingsArgs =
        com.pulumi.azurenative.migrate.inputs.DiskEncryptionSetResourceSettingsArgs.builder()
            .resourceType(resourceType.applyValue({ args0 -> args0 }))
            .targetResourceGroupName(targetResourceGroupName?.applyValue({ args0 -> args0 }))
            .targetResourceName(targetResourceName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DiskEncryptionSetResourceSettingsArgs].
 */
@PulumiTagMarker
public class DiskEncryptionSetResourceSettingsArgsBuilder internal constructor() {
    private var resourceType: Output<String>? = null

    private var targetResourceGroupName: Output<String>? = null

    private var targetResourceName: Output<String>? = null

    /**
     * @param value The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
     * Expected value is 'Microsoft.Compute/diskEncryptionSets'.
     */
    @JvmName("dhhmbxlxqbrldaoh")
    public suspend fun resourceType(`value`: Output<String>) {
        this.resourceType = value
    }

    /**
     * @param value Gets or sets the target resource group name.
     */
    @JvmName("dmonnngmrdigyiaw")
    public suspend fun targetResourceGroupName(`value`: Output<String>) {
        this.targetResourceGroupName = value
    }

    /**
     * @param value Gets or sets the target Resource name.
     */
    @JvmName("dvmidrjaktqqhepf")
    public suspend fun targetResourceName(`value`: Output<String>) {
        this.targetResourceName = value
    }

    /**
     * @param value The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
     * Expected value is 'Microsoft.Compute/diskEncryptionSets'.
     */
    @JvmName("hbbqtpnsbvbdgans")
    public suspend fun resourceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceType = mapped
    }

    /**
     * @param value Gets or sets the target resource group name.
     */
    @JvmName("tsfagnrtdlnfcvqt")
    public suspend fun targetResourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetResourceGroupName = mapped
    }

    /**
     * @param value Gets or sets the target Resource name.
     */
    @JvmName("qeodfeyyswwjxsty")
    public suspend fun targetResourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetResourceName = mapped
    }

    internal fun build(): DiskEncryptionSetResourceSettingsArgs =
        DiskEncryptionSetResourceSettingsArgs(
            resourceType = resourceType ?: throw PulumiNullFieldException("resourceType"),
            targetResourceGroupName = targetResourceGroupName,
            targetResourceName = targetResourceName ?: throw PulumiNullFieldException("targetResourceName"),
        )
}
